#!/bin/bash

# Define the directory containing the DTB files
dtb_dir="/boot/dtb"

# Iterate over each DTB file in the directory
for dtb_file in "$dtb_dir"/*.dtb; do
    # Extract the filename without the extension
    base_name=$(basename "$dtb_file" .dtb)

    # Backup the original DTB file
    cp "$dtb_file" "$dtb_file.back"

    # Convert DTB to DTS
    dts_file="$dtb_dir/$base_name.dts"
    dtc -I dtb -O dts -o "$dts_file" "$dtb_file"

    # Check if the conversion succeeded
    if [[ $? -ne 0 ]]; then
        echo "Failed to convert $dtb_file to DTS. Skipping."
        continue
    fi

    # Modify the DTS file
    sed -i 's/port-index = <0x01>;/port-index = <0x00>;/g' "$dts_file"
    sed -i 's/tegra_sinterface = "serial_b";/tegra_sinterface = "serial_a";/g' "$dts_file"

    # Convert the modified DTS back to DTB
    dtc -I dts -O dtb -o "$dtb_file" "$dts_file"

    # Check if the conversion back succeeded
    if [[ $? -eq 0 ]]; then
        echo "Successfully modified and saved: $dtb_file"
    else
        echo "Failed to convert $dts_file back to DTB. Restoring backup."
        mv "$dtb_file.back" "$dtb_file"
    fi

    # Remove the temporary DTS file
    rm "$dts_file"

done

# Print completion message
echo "All DTB files processed. Original files are backed up with .back suffix."
